# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
✨ Add `CloudAnnData` | [26](https://github.com/laminlabs/lndb-storage/pull/26) | [falexwolf](https://github.com/falexwolf) | 2023-04-24 | 0.2rc6
📝 Drastically simplify streaming guide | [25](https://github.com/laminlabs/lndb-storage/pull/25) | [falexwolf](https://github.com/falexwolf) | 2023-04-24 |
✅ Add additional tests for replace | [24](https://github.com/laminlabs/lndb-storage/pull/24) | [Koncopd](https://github.com/Koncopd) | 2023-04-23 |
✅ Check add with key | [20](https://github.com/laminlabs/lndb-storage/pull/20) | [Koncopd](https://github.com/Koncopd) | 2023-04-16 | 0.2rc5
♻️ Refactoring | [19](https://github.com/laminlabs/lndb-storage/pull/19) | [Koncopd](https://github.com/Koncopd) | 2023-04-16 |
♻️ Remove call to nbproject in progress bar | [18](https://github.com/laminlabs/lndb-storage/pull/18) | [falexwolf](https://github.com/falexwolf) | 2023-04-14 | 0.2rc4
✅ Introduce separate upload guide | [14](https://github.com/laminlabs/lndb-storage/pull/14) | [falexwolf](https://github.com/falexwolf) | 2023-04-09 | 0.2rc3
💚 Attempt fix CI | [12](https://github.com/laminlabs/lndb-storage/pull/12) | [falexwolf](https://github.com/falexwolf) | 2023-04-09 |
🚚 Move `UPath` back to `lndb` | [11](https://github.com/laminlabs/lndb-storage/pull/11) | [falexwolf](https://github.com/falexwolf) | 2023-04-08 |
✅ Add test for replace and stage | [10](https://github.com/laminlabs/lndb-storage/pull/10) | [Koncopd](https://github.com/Koncopd) | 2023-04-04 |
➕ Add upath to deps | [9](https://github.com/laminlabs/lndb-storage/pull/9) | [Koncopd](https://github.com/Koncopd) | 2023-03-26 | 0.2rc2
➖ Remove lndb as explicit dependency | [7](https://github.com/laminlabs/lndb-storage/pull/7) | [Koncopd](https://github.com/Koncopd) | 2023-03-26 | 0.2rc1
🚚 Rename `DObject` to `File` | [8](https://github.com/laminlabs/lndb-storage/pull/8) | [falexwolf](https://github.com/falexwolf) | 2023-03-24 |
✅ Test streaming here | [6](https://github.com/laminlabs/lndb-storage/pull/6) | [Koncopd](https://github.com/Koncopd) | 2023-03-17 |
♻️ Move the rest of storage code here | [4](https://github.com/laminlabs/lndb-storage/pull/4) | [Koncopd](https://github.com/Koncopd) | 2023-03-14 |
👷 Update with latest cookiecutter | [5](https://github.com/laminlabs/lndb-storage/pull/5) | [falexwolf](https://github.com/falexwolf) | 2023-03-14 |
🔨 Update storage code | [3](https://github.com/laminlabs/lndb-storage/pull/3) | [Koncopd](https://github.com/Koncopd) | 2023-03-11 |
🎉 Start moving code from lamindb | [1](https://github.com/laminlabs/lndb-storage/pull/1) | [Koncopd](https://github.com/Koncopd) | 2022-11-20 |
